Package: pez
Type: Package
Title: Phylogenetics for the Environmental Sciences
Version: 1.2-5
Authors@R: c(person(given = c("William", "D."),
                      family = "Pearse",
                      role = c("aut", "cre"),
                      email = "will.pearse@gmail.com"),
               person(given = c("Marc", "W."),
                      family = "Cadotte",
                      role = "aut"),
               person(given = "Jeannine",
                      family = "Cavender-Bares",
                      role = "aut"),
               person(given = c("Anthony", "R."),
                      family = "Ives",
                      role = "aut"),
               person(given = "Caroline",
                      family = "Tucker",
                      role = "aut"),
               person(given = c("Steve", "C."),
                      family = "Walker",
                      role = "aut"),
               person(given = c("Matthew", "R."),
                      family = "Helmus",
                      role = "aut"))
Maintainer: William D. Pearse <will.pearse@gmail.com>
Description: Eco-phylogenetic and community phylogenetic analyses.
    Keeps community ecological and phylogenetic data matched up and
    comparable using 'comparative.comm' objects. Wrappers for common
    community phylogenetic indices ('pez.shape', 'pez.evenness',
    'pez.dispersion', and 'pez.dissimilarity' metrics). Implementation
    of Cavender-Bares (2004) correlation of phylogenetic and
    ecological matrices ('fingerprint.regression'). Phylogenetic
    Generalised Linear Mixed Models (PGLMMs; 'pglmm') following Ives &
    Helmus (2011) and Rafferty & Ives (2013). Simulation of null
    assemblages, traits, and phylogenies ('scape', 'sim.meta.comm').
License: GPL-3
VignetteBuilder: knitr
Suggests: knitr (>= 1.6), lme4 (>= 1.1-7), formatR (>= 1.7)
Imports: caper (>= 0.5-2), picante (>= 1.6-2), quantreg (>= 5.05),
        mvtnorm (>= 1.0-0), vegan (>= 2.0-10), ade4 (>= 1.6-2), FD (>=
        1.0-12), Matrix (>= 1.1-4), methods (>= 3.1.0), animation (>=
        2.4-0), phytools (>= 0.6-60)
Depends: ape (>= 3.1-4)
NeedsCompilation: no
Repository: CRAN
Encoding: UTF-8
RoxygenNote: 7.3.2
Packaged: 2025-08-27 17:59:04 UTC; will
Author: William D. Pearse [aut, cre],
  Marc W. Cadotte [aut],
  Jeannine Cavender-Bares [aut],
  Anthony R. Ives [aut],
  Caroline Tucker [aut],
  Steve C. Walker [aut],
  Matthew R. Helmus [aut]
Date/Publication: 2025-08-28 17:00:02 UTC
Built: R 4.6.0; ; 2026-04-26 09:23:03 UTC; unix
