# Generated by roxygen2: do not edit by hand

S3method("[",comparative.comm)
S3method(as.data.frame,comparative.comm)
S3method(comm.dist,comparative.comm)
S3method(comm.dist,matrix)
S3method(funct.phylo.dist,comparative.comm)
S3method(phylo.dist,comparative.comm)
S3method(phylo.dist,phylo)
S3method(pianka.dist,comparative.comm)
S3method(pianka.dist,matrix)
S3method(plot,communityPGLMM)
S3method(plot,comparative.comm)
S3method(plot,eco.xxx.regression)
S3method(plot,eco.xxx.regression.list)
S3method(plot,fingerprint.regression)
S3method(print,comparative.comm)
S3method(print,eco.xxx.regression)
S3method(print,eco.xxx.regression.list)
S3method(print,fingerprint.regression)
S3method(summary,communityPGLMM)
S3method(summary,eco.xxx.regression)
S3method(summary,eco.xxx.regression.list)
S3method(summary,fingerprint.regression)
S3method(traits.dist,comparative.comm)
S3method(traits.dist,data.frame)
S3method(traits.dist,default)
S3method(within,comparative.comm)
export("comm<-")
export("env<-")
export("phy<-")
export("sites<-")
export("species<-")
export("traits<-")
export("tree<-")
export(.aed)
export(.bed)
export(.comdist)
export(.d)
export(.delta)
export(.dist.fd)
export(.eaed)
export(.eco.null)
export(.eed)
export(.eigen.sum)
export(.gamma)
export(.haed)
export(.hed)
export(.iac)
export(.innd)
export(.kappa)
export(.lambda)
export(.metric.null)
export(.mipd)
export(.mntd)
export(.mpd)
export(.pae)
export(.pcd)
export(.pd)
export(.pe)
export(.phylo.entropy)
export(.phylosor)
export(.pse)
export(.psr)
export(.psv)
export(.rao)
export(.scheiner)
export(.ses)
export(.ses.innd)
export(.ses.mipd)
export(.ses.mntd)
export(.ses.mpd)
export(.ses.vntd)
export(.ses.vpd)
export(.simpson.phylogenetic)
export(.sqrt.phy)
export(.taxon)
export(.unifrac)
export(.vntd)
export(.vpd)
export(ConDivSim)
export(assemblage.phylogenies)
export(comm)
export(comm.dist)
export(communityPGLMM)
export(communityPGLMM.binary)
export(communityPGLMM.binary.LRT)
export(communityPGLMM.gaussian)
export(communityPGLMM.matrix.structure)
export(communityPGLMM.predicted.values)
export(comparative.comm)
export(congeneric.impute)
export(congeneric.merge)
export(dist.func.default)
export(drop_tip)
export(eco.env.regression)
export(eco.phy.regression)
export(eco.scape)
export(eco.trait.regression)
export(edge2phylo)
export(env)
export(env.names)
export(fibre.plot)
export(fingerprint.regression)
export(funct.phylo.dist)
export(generic.metrics)
export(generic.null)
export(pez.dispersion)
export(pez.dissimilarity)
export(pez.endemism)
export(pez.evenness)
export(pez.shape)
export(phy)
export(phy.signal)
export(phylo.dist)
export(pianka.dist)
export(princompOne)
export(scape)
export(sim.bd.phy)
export(sim.bd.tr.phy)
export(sim.meta.comm)
export(sim.meta.phy.comm)
export(sites)
export(species)
export(trait.asm)
export(trait.names)
export(traitgram.cc)
export(traits)
export(traits.dist)
export(tree)
importClassesFrom(Matrix,RsparseMatrix)
importClassesFrom(Matrix,dsCMatrix)
importFrom(FD,dbFD)
importFrom(ade4,newick2phylog)
importFrom(ade4,scalewt)
importFrom(animation,saveGIF)
importFrom(ape,as.phylo)
importFrom(ape,as.phylo.formula)
importFrom(ape,bind.tree)
importFrom(ape,branching.times)
importFrom(ape,compute.brlen)
importFrom(ape,cophenetic.phylo)
importFrom(ape,corBlomberg)
importFrom(ape,drop.tip)
importFrom(ape,extract.clade)
importFrom(ape,gammaStat)
importFrom(ape,getMRCA)
importFrom(ape,is.binary.phylo)
importFrom(ape,is.rooted)
importFrom(ape,is.ultrametric)
importFrom(ape,multi2di)
importFrom(ape,node.depth.edgelength)
importFrom(ape,plot.phylo)
importFrom(ape,tiplabels)
importFrom(ape,vcv)
importFrom(ape,vcv.phylo)
importFrom(ape,write.tree)
importFrom(caper,VCV.array)
importFrom(caper,clade.matrix)
importFrom(caper,coef.pgls)
importFrom(caper,comparative.data)
importFrom(caper,contrCalc)
importFrom(caper,pgls)
importFrom(caper,phylo.d)
importFrom(caper,summary.pgls)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,grey)
importFrom(graphics,abline)
importFrom(graphics,image)
importFrom(graphics,layout)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,rect)
importFrom(graphics,text)
importFrom(methods,as)
importFrom(methods,is)
importFrom(methods,show)
importFrom(mvtnorm,rmvnorm)
importFrom(phytools,getDescendants)
importFrom(picante,Kcalc)
importFrom(picante,comdist)
importFrom(picante,evol.distinct)
importFrom(picante,mntd)
importFrom(picante,mpd)
importFrom(picante,pcd)
importFrom(picante,pd)
importFrom(picante,phylosor)
importFrom(picante,psd)
importFrom(picante,pse)
importFrom(picante,psv)
importFrom(picante,randomizeMatrix)
importFrom(picante,raoD)
importFrom(picante,ses.mntd)
importFrom(picante,ses.mpd)
importFrom(picante,ses.pd)
importFrom(picante,traitgram)
importFrom(picante,unifrac)
importFrom(quantreg,print.rq)
importFrom(quantreg,rq)
importFrom(quantreg,summary.rq)
importFrom(stats,as.dist)
importFrom(stats,binomial)
importFrom(stats,coef)
importFrom(stats,cophenetic)
importFrom(stats,dist)
importFrom(stats,glm)
importFrom(stats,hclust)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.response)
importFrom(stats,optim)
importFrom(stats,optimize)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,prcomp)
importFrom(stats,princomp)
importFrom(stats,printCoefmat)
importFrom(stats,quantile)
importFrom(stats,rbinom)
importFrom(stats,reorder)
importFrom(stats,reshape)
importFrom(stats,resid)
importFrom(stats,rexp)
importFrom(stats,rnorm)
importFrom(stats,rpois)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,uniroot)
importFrom(stats,var)
importFrom(utils,capture.output)
importFrom(vegan,decostand)
importFrom(vegan,mantel)
importFrom(vegan,taxondive)
importMethodsFrom(Matrix,"%*%")
importMethodsFrom(Matrix,determinant)
importMethodsFrom(Matrix,diag)
importMethodsFrom(Matrix,solve)
importMethodsFrom(Matrix,t)
